aboutsummaryrefslogtreecommitdiffstats
path: root/components/script/script_thread.rs
diff options
context:
space:
mode:
Diffstat (limited to 'components/script/script_thread.rs')
-rw-r--r--components/script/script_thread.rs8
1 files changed, 4 insertions, 4 deletions
diff --git a/components/script/script_thread.rs b/components/script/script_thread.rs
index e0998db7b2b..9118b79aa62 100644
--- a/components/script/script_thread.rs
+++ b/components/script/script_thread.rs
@@ -1060,7 +1060,7 @@ impl ScriptThread {
}
/// Process compositor events as part of a "update the rendering task".
- fn proces_pending_input_events(&self, pipeline_id: PipelineId, can_gc: CanGc) {
+ fn process_pending_input_events(&self, pipeline_id: PipelineId, can_gc: CanGc) {
let Some(document) = self.documents.borrow().find_document(pipeline_id) else {
warn!("Processing pending compositor events for closed pipeline {pipeline_id}.");
return;
@@ -1199,13 +1199,13 @@ impl ScriptThread {
continue;
}
// TODO(#31581): The steps in the "Revealing the document" section need to be implemente
// `proces_pending_input_events` handles the focusing steps as well as other events
// from the compositor.
// TODO: Should this be broken and to match the specification more closely? For instance see
// https://html.spec.whatwg.org/multipage/#flush-autofocus-candidates.
- self.proces_pending_input_events(*pipeline_id, can_gc);
+ self.process_pending_input_events(*pipeline_id, can_gc);
// TODO(#31665): Implement the "run the scroll steps" from
// https://drafts.csswg.org/cssom-view/#document-run-the-scroll-steps.
@@ -1199,13 +1199,13 @@ impl ScriptThread {
continue;
}
- // TODO(#31581): The steps in the "Revealing the document" section need to be implemente
- // `proces_pending_input_events` handles the focusing steps as well as other events
+ // TODO(#31581): The steps in the "Revealing the document" section need to be implemented
+ // `process_pending_input_events` handles the focusing steps as well as other events
// from the compositor.
// TODO: Should this be broken and to match the specification more closely? For instance see